@@ -334,6 +334,11 @@ func (optr *Operator) sync(key string) error {
 		return err
 	}
 
+	optrVersion, _ := optr.vStore.Get("operator")
+	if imgs.ReleaseVersion != optrVersion {
+		return fmt.Errorf("refusing to read images.json version %q, operator version %q", imgs.ReleaseVersion, optrVersion)
+	}
+
 	// sync up CAs
 	etcdCA, err := optr.getCAsFromConfigMap("openshift-config", "etcd-serving-ca", "ca-bundle.crt")
 	if err != nil {
@@ -411,11 +416,11 @@ func (optr *Operator) sync(key string) error {
 	// syncFuncs is the list of sync functions that are executed in order.
 	// any error marks sync as failure but continues to next syncFunc
 	var syncFuncs = []syncFunc{
-		{"pools", optr.syncMachineConfigPools},
-		{"mcd", optr.syncMachineConfigDaemon},
-		{"mcc", optr.syncMachineConfigController},
-		{"mcs", optr.syncMachineConfigServer},
-		{"required-pools", optr.syncRequiredMachineConfigPools},
+		{"MachineConfigPools", optr.syncMachineConfigPools},
+		{"MachineConfigDaemon", optr.syncMachineConfigDaemon},
+		{"MachineConfigController", optr.syncMachineConfigController},
+		{"MachineConfigServer", optr.syncMachineConfigServer},
+		{"RequiredPools", optr.syncRequiredMachineConfigPools},
 	}
 	return optr.syncAll(rc, syncFuncs)
 }
